//
//  CustomPopView.swift
//  MyWeibo
//
//  Created by gongwenkai on 16/6/17.
//  Copyright © 2016年 gongwenkai. All rights reserved.
//

import Foundation
import UIKit
let  CurrentScreenBounds = UIScreen.mainScreen().bounds

//枚举，popView出现的位置
enum PopViewPosition : Int {
    case left
    case center
    case right
}


//纯粹练习protocol
//兼容objc做一个可选方法，popView消失前做一些事
@objc protocol PopViewDelegate {
    
    optional func popViewWillDismiss(popView popView:CustomPopView)

}

class CustomPopView: UIView{
    var meunImageView: UIImageView?
    var cover :UIButton?
    var contentView:UIView?
    var delegate: PopViewDelegate?
    //获得arrowPosition时定义background的背景图片（箭头不同）
    var _arrowPosition:PopViewPosition?
    var arrowPosition:PopViewPosition?{
        willSet{
            self.arrowPosition = _arrowPosition
        }
        //类似oc的重写set方法
        didSet{
            switch arrowPosition! {
            case PopViewPosition.left:
                self.meunImageView?.image = resizedImage("popover_background_left")
            case PopViewPosition.center:
                self.meunImageView?.image = resizedImage("popover_background")
            case PopViewPosition.right:
                self.meunImageView?.image = resizedImage("popover_background_right")
            }

        }
    }

    //重写父类初始化方法
    override init(frame: CGRect) {
        super.init(frame: frame)
        self.frame = CurrentScreenBounds;
        let cover = UIButton.init()
        cover.backgroundColor = UIColor.clearColor()
        cover.addTarget(self, action: #selector(CustomPopView.coverClick), forControlEvents: .TouchUpInside)
        self.addSubview(cover)
        self.cover = cover;
        let meunImageView = UIImageView.init()
        meunImageView.userInteractionEnabled = true
        self.addSubview(meunImageView)
        self.meunImageView = meunImageView;
        self.cover?.frame = self.bounds
        
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    //菜单view
    func menuWithContentView(contentView:UIView)->AnyObject{
        return initWithContentView(contentView)
    }
    
    func initWithContentView(contentView:UIView)->AnyObject{
        self.contentView = contentView
        return self
    }

//    //设置背景图片
//    func setBackgroundImage(backgroundImag:UIImage){
//        meunImageView?.image = backgroundImag
//    }

    //点击消失
    func dismiss(){
        
        //消失前进行的一些操作
//        self.delegate?.popViewWillDismiss!(popView: self)

        //添加消失动画，延时remove
        UIView.beginAnimations(nil, context: nil)
        UIView.setAnimationDuration(0.5)
        self.alpha = 0
        UIView.commitAnimations()
        let time: NSTimeInterval = 0.5
        let delay = dispatch_time(DISPATCH_TIME_NOW,
                                  Int64(time * Double(NSEC_PER_SEC)))
        dispatch_after(delay, dispatch_get_main_queue()) {
           self.removeFromSuperview()
        }
    }
    
    //点击背景消失
    func coverClick()  {
        dismiss()
    }
    
    //设置image大小,拉伸图片
    func resizedImage(name:String) -> UIImage {
        let image = UIImage.init(named: name)
        return (image?.stretchableImageWithLeftCapWidth(Int(image!.size.width * 0.5), topCapHeight: Int(image!.size.height * 0.5)))!
        
    }
    
    //在指定区域显示菜单
    func showInRect(){
        let window:UIWindow = UIApplication.sharedApplication().windows.last!
        window.addSubview(self)
        self.alpha = 0
        meunImageView?.addSubview(contentView!)
        
        //淡出动画
        UIView.beginAnimations(nil, context: nil)
        UIView.setAnimationDuration(0.5)
        self.alpha = 1
        UIView.commitAnimations()
    }

    func setArrowPosition(arrowPosition:PopViewPosition) {
        self.arrowPosition = arrowPosition
        switch arrowPosition {
        case .left:
            self.meunImageView?.image = resizedImage("popover_background_left")
        case .center:
            self.meunImageView?.image = resizedImage("popover_background")
        case .right:
            self.meunImageView?.image = resizedImage("popover_background_right")
        }
    }
    
}
